<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px" @submit.native.prevent>
      <el-form-item label="施工批次" prop="batch">
        <el-input
          v-model="queryParams.batch"
          placeholder="请输入施工批次"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
        >删除</el-button>
      </el-col>
    </el-row>

    <el-table v-loading="loading" :data="constructionBatchList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="序号" type="index" align="center">
        <template slot-scope="scope">
          <span>{{(queryParams.pageNum - 1) * queryParams.pageSize + scope.$index + 1}}</span>
        </template>
      </el-table-column>
      <el-table-column label="施工批次" align="center" prop="batch" show-overflow-tooltip />
      <el-table-column label="施工周期" align="center" width="180" show-overflow-tooltip>
        <template slot-scope="scope">
          <span>{{ scope.row.startDate + ' - ' + scope.row.endDate }}</span>
        </template>
      </el-table-column>
      <el-table-column label="负责人" align="center" prop="userId_dictText" show-overflow-tooltip />
      <el-table-column label="团队成员" align="center" prop="teamMembers" show-overflow-tooltip />
      <el-table-column label="备注" align="center" prop="remarks" show-overflow-tooltip />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            class="del-btn"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改施工批次对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body :close-on-click-modal="false">
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="施工批次" prop="batch">
          <el-input v-model="form.batch" maxlength="64" show-word-limit placeholder="请输入施工批次" />
        </el-form-item>
        <el-form-item label="施工周期" prop="date">
          <el-date-picker
              style="width: 100%"
              v-model="form.date"
              type="daterange"
              value-format="yyyy-MM-dd"
              range-separator="至"
              start-placeholder="开始日期"
              end-placeholder="截至日期">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="负责人" prop="userId">
          <el-select v-model="form.userId" style="width: 100%" filterable placeholder="请选择负责人">
            <el-option
                v-for="item in userList"
                :key="item.userId"
                :label="item.nickName"
                :value="item.userId"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="团队成员" prop="teamMembers">
          <el-input v-model="form.teamMembers" type="textarea" rows="4" maxlength="64" show-word-limit placeholder="请输入团队成员" />
        </el-form-item>
        <el-form-item label="备注" prop="remarks">
          <el-input v-model="form.remarks" type="textarea" rows="4" maxlength="512" show-word-limit placeholder="请输入内容" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listConstructionBatch, getConstructionBatch, delConstructionBatch, addConstructionBatch, updateConstructionBatch } from "@/api/oa/constructionBatch";
import {listUser} from '@/api/common/common'

export default {
  name: "ConstructionBatch",
  props: {
    schoolId: {
      type: Number,
      default: undefined
    }
  },
  data() {
    return {
      // 按钮loading
      buttonLoading: false,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 施工批次表格数据
      constructionBatchList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        batch: undefined,
        startDate: undefined,
        endDate: undefined,
        userId: undefined,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        id: [
          { required: true, message: "不能为空", trigger: "blur" }
        ],
        batch: [
          { required: true, message: "施工批次不能为空", trigger: "blur" }
        ],
        userId: [
          { required: true, message: "负责人不能为空", trigger: "blur" }
        ],
        date: [
          { required: true, message: "施工周期不能为空", trigger: "blur" }
        ]
      },
      userList: []
    };
  },
  watch: {
    'schoolId': function () {
      this.getList()
    }
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询施工批次列表 */
    getList() {
      this.loading = true;
      listConstructionBatch(Object.assign({}, this.queryParams, {schoolId: this.schoolId})).then(response => {
        this.constructionBatchList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    getUser() {
      listUser().then(r => {
        this.userList = r.data;
      })
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: undefined,
        batch: undefined,
        startDate: undefined,
        endDate: undefined,
        userId: undefined,
        teamMembers: undefined,
        remarks: undefined,
        createTime: undefined,
        createBy: undefined,
        updateBy: undefined,
        updateTime: undefined,
        delFlag: undefined
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.getUser();
      this.open = true;
      this.title = "添加施工批次";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.loading = true;
      this.reset();
      const id = row.id || this.ids
      getConstructionBatch(id).then(response => {
        this.loading = false;
        // this.form = response.data;
        const localDate = [response.data.startDate, response.data.endDate];
        this.form = Object.assign({}, response.data, {date: localDate})
        this.open = true;
        this.title = "修改施工批次";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        this.form.startDate = this.form.date[0];
        this.form.endDate = this.form.date[1];
        if (valid) {
          this.buttonLoading = true;
          this.form.schoolId = this.schoolId;
          if (this.form.id != null) {
            updateConstructionBatch(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            }).finally(() => {
              this.buttonLoading = false;
            });
          } else {
            addConstructionBatch(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            }).finally(() => {
              this.buttonLoading = false;
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除？').then(() => {
        this.loading = true;
        return delConstructionBatch(ids);
      }).then(() => {
        this.loading = false;
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).finally(() => {
        this.loading = false;
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('oa/constructionBatch/export', {
        ...this.queryParams
      }, `constructionBatch_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
